// -------------------------------------------------------------------------------- 
//!  @file  bitmap.h                                                                
//!  ビットマップ処理のヘッダファイル                                               
//                                                                                  
//   Copyright (C) 2024 lsluk, All rights reserved.                                 
//   http://vdmgr.g2.xrea.com/index.html                                            
// -------------------------------------------------------------------------------- 
#ifndef __BTRADIO__BITMAP_H__INCLUDED__
#define __BTRADIO__BITMAP_H__INCLUDED__


	enum {
		BI_RGB						=	0,							//!< 非圧縮形式
		BI_RLE8						=	1,							//!< 8bit RLE
		BI_RLE4						=	2,							//!< 4bit RLE
		BI_BITFIELDS				=	3,							//!< 非圧縮形式カラーマスク
	} ;

	//! ビットマップファイルヘッダ
	typedef struct tagBITMAPFILEHEADER {
		uint16_t					bfType ;						//!< 識別子
		uint32_t					bfSize ;						//!< ファイルサイズ
		uint16_t					bfReserved1 ;					//!< 予約１
		uint16_t					bfReserved2 ;					//!< 予約２
		uint32_t					bfOffBits ;						//!< 画像データまでのバイト数
	} __attribute__ ((packed)) BITMAPFILEHEADER ;

	//! ビットマップ情報ヘッダ
	typedef struct tagBITMAPINFOHEADER {
		uint32_t					biSize ;						//!< サイズ
		int32_t						biWidth ;						//!< 画像幅
		int32_t						biHeight ;						//!< 画像高さ
		uint16_t					biPlanes ;						//!< プレーン数
		uint16_t					biBitCount ;					//!< ピクセルあたりのビット数
		uint32_t					biCompression ;					//!< 圧縮形式
		uint32_t					biSizeImage ;					//!< 画像サイズ
		int32_t						biXPelsPerMeter ;				//!< メートルあたりの幅
		int32_t						biYPelsPerMeter ;				//!< メートルあたりの高さ
		uint32_t					biClrUsed ;						//!< カラーテーブル内のカラーインデックス数
		uint32_t					biClrImportant ;				//!< 重要と見なされるカラーインデックス数
	} BITMAPINFOHEADER ;

	//! 赤緑青色
	typedef struct tagRGBQUAD {
		uint8_t						rgbBlue ;						//!< 青
		uint8_t						rgbGreen ;						//!< 緑
		uint8_t						rgbRed ;						//!< 赤
		uint8_t						rgbReserved ;					//!< 予約(0)
	} RGBQUAD ;

	//! ビットマップ情報
	typedef struct tagBITMAPINFO {
		BITMAPINFOHEADER			bmiHeader ;						//!< ビットマップ情報ヘッダ
		RGBQUAD						bmiColors[1] ;					//!< カラーテーブル
	} BITMAPINFO ;


extern BITMAPINFO *bitmap_load( const char *p_fileName ) ;
extern int         bitmap_free( BITMAPINFO *p_bi ) ;


#endif//__BTRADIO__BITMAP_H__INCLUDED__
