// -------------------------------------------------------------------------------- 
//!  @file  bluetooth.c                                                             
//!  Bluetooth 処理のソースファイル                                                 
//                                                                                  
//   Copyright (C) 2024 lsluk, All rights reserved.                                 
//   http://vdmgr.g2.xrea.com/index.html                                            
// -------------------------------------------------------------------------------- 
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <bluetooth/bluetooth.h>
#include <bluetooth/hci.h>
#include <bluetooth/hci_lib.h>


// -------------------------------------------------------------------------------- 
//!  接続中か調べる                                                                 
//!                                                                                 
//!  @param [in] p_bdaddr  Bluetooth デバイスアドレス                               
//!  @retval      0        未接続                                                   
//!  @retval      1        接続中                                                   
//!  @retval     -1        異常終了                                                 
// -------------------------------------------------------------------------------- 
int bluetooth_isConnect( const char *p_bdaddr )
{
	struct {
		struct hci_conn_info_req	req ;
		struct hci_conn_info		info ;
	} hci_conn ;
	bdaddr_t						bdaddr ;
	int								result, dev_id, dd ;


	str2ba(&p_bdaddr[0], &bdaddr) ;

	dev_id = hci_get_route( &bdaddr ) ;
	if( dev_id < 0 ) {
		return -1 ;
	}

	dd = hci_open_dev( dev_id ) ;
	if( dd < 0 ) {
		return -1 ;
	}

	memcpy(&hci_conn.req.bdaddr, &bdaddr, sizeof( bdaddr )) ;
	hci_conn.req.type = ACL_LINK ;
	result            = ioctl(dd, HCIGETCONNINFO, (unsigned long)&hci_conn) ;
	if( result >= 0 ) {
		result = (hci_conn.info.state == BT_CONNECTED) ;
	}

	close( dd ) ;

	return result ;
}
