// -------------------------------------------------------------------------------- 
//!  @file  common.h                                                                
//!  共通処理のソースファイル                                                       
//                                                                                  
//   Copyright (C) 2024 lsluk, All rights reserved.                                 
//   http://vdmgr.g2.xrea.com/index.html                                            
// -------------------------------------------------------------------------------- 
#ifndef __BTRADIO__COMMON_H__INCLUDED__
#define __BTRADIO__COMMON_H__INCLUDED__


#include <limits.h>


#define countof( s )				(int )(sizeof( s )/sizeof( s[0] ))		//!< 配列数取得

	//! ピン番号
	enum {
		PIN_RED,													//!< 赤ボタン
		PIN_YELLOW,													//!< 黄ボタン
		PIN_BLUE,													//!< 青ボタン
		PIN_GREEN,													//!< 緑ボタン
		PIN_MAX,													//!< 最大値
	} ;

	//! ラジオ局情報
	typedef struct {
		char						type[16] ;						//!< 種類
		char						id[32] ;						//!< ラジオ局 ID
		uint32_t					image ;							//!< 画像データインデックス
	} STATIONINFO ;

	//! 設定情報
	typedef struct {
		//! スクリプト
		struct {
			char					play[PATH_MAX] ;				//!< 再生スクリプト
			char					record[PATH_MAX] ;				//!< 録音スクリプト
		} script ;
		char						outputRecord[PATH_MAX] ;		//!< 録音ファイル出力ディレクトリ
		char						i2cDev[PATH_MAX] ;				//!< I2C デバイス
		int							pin[PIN_MAX] ;					//!< ピン番号
		char						btAddr[17+1] ;					//!< Bluetooth デバイスアドレス
		char						wlanIf[16+1] ;					//!< WLAN インタフェース
		char						mixer[64+1] ;					//!< ミキサー
		char						selem[64+1] ;					//!< シンプルミキサー要素
		int							contrast ;						//!< コントラスト
		int							displayOffCount ;				//!< 表示オフ秒数
		STATIONINFO					*p_stationInfo ;				//!< ラジオ局情報
		int							stationInfoCount ;				//!< ラジオ局情報数
	} SETUPINFO ;


extern SETUPINFO					 g_setupInfo ;					//!< 設定情報


extern char    *ltrim( char *p_string ) ;
extern void     rtrim( char *p_string ) ;
extern char    *trim( char *p_string ) ;
extern void     msleep( int msec ) ;
extern uint32_t getCurrentTime( void ) ;
extern void     setCurrentDir( char const *p_path ) ;
extern int      loadSetupFile( const char *p_fileName ) ;


#endif//__BTRADIO__COMMON_H__INCLUDED__
