// -------------------------------------------------------------------------------- 
//!  @file  inifile.h                                                               
//!  ini ファイル制御のヘッダファイル                                               
//                                                                                  
//   Copyright (C) 2024 lsluk, All rights reserved.                                 
//   http://vdmgr.g2.xrea.com/index.html                                            
// -------------------------------------------------------------------------------- 
#ifndef __BTRADIO__INIFILE_H__INCLUDED__
#define __BTRADIO__INIFILE_H__INCLUDED__


typedef struct inisectioninfo		INISECTIONINFO ;				//!< セクション情報


	enum {
		INIFILE_SECTION_MAX			=	256,						//!< セクション最大数
		INIFILE_KEY_MAX				=	8192,						//!< キー最大数
	} ;

	//! キー情報
	typedef struct {
		int							line ;							//!< 定義行
		const char					*p_name ;						//!< 名前
		char						*p_param ;						//!< パラメータ
		INISECTIONINFO				*p_sectionInfo ;				//!< 定義セクション情報
	} INIKEYINFO ;

	//! セクション情報
	struct inisectioninfo {
		int							line ;							//!< 定義行
		const char					*p_name ;						//!< 名前
		INIKEYINFO					*p_keyInfo ;					//!< キー情報
		int							keyInfoCount ;					//!< キー情報数
	} ;

	//! ini ファイル情報
	typedef struct {
		INISECTIONINFO				sectionInfo[INIFILE_SECTION_MAX] ;	//!< セクション情報
		int							sectionInfoCount ;					//!< セクション情報数
		INIKEYINFO					keyInfo[INIFILE_KEY_MAX] ;			//!< キー情報
		int							keyInfoCount ;						//!< キー情報数
	} INIFILEINFO ;


extern INIFILEINFO    *initfile_open( const char *p_fileName ) ;
extern void            initfile_close( INIFILEINFO *p_fileInfo ) ;
extern INISECTIONINFO *initfile_getSection(INIFILEINFO *p_fileInfo, const char *p_name) ;
extern INIKEYINFO     *initfile_getKey(INISECTIONINFO *p_sectionInfo, INIKEYINFO *p_keyInfo, const char *p_name) ;
extern INIKEYINFO     *initfile_getSectionKey(INIFILEINFO *p_fileInfo, const char *p_sectionName, const char *p_keyName) ;
extern bool            initfile_getString(INIFILEINFO *p_fileInfo, const char *p_sectionName, const char *p_keyName, char *p_string, int size) ;
extern bool            initfile_getValue(INIFILEINFO *p_fileInfo, const char *p_sectionName, const char *p_keyName, int min, int max, int *p_value) ;


#endif//__BTRADIO__INIFILE_H__INCLUDED__
