// -------------------------------------------------------------------------------- 
//!  @file  ssd1306.h                                                               
//!  SSD1306 制御のヘッダファイル                                                   
//                                                                                  
//   Copyright (C) 2024 lsluk, All rights reserved.                                 
//   http://vdmgr.g2.xrea.com/index.html                                            
// -------------------------------------------------------------------------------- 
#ifndef __BTRADIO__SSD1306_H__INCLUDED__
#define __BTRADIO__SSD1306_H__INCLUDED__


	enum {
		SSD1306_SLAVE_ADDR			=	0x3c,						//!< スレーブアドレス
		SSD1306_WIDTH				=	128,						//!< 表示幅
		SSD1306_HEIGHT				=	64,							//!< 表示高さ
		SSD1306_LINEHEIGHT			=	8,							//!< １行あたりの高さ
		SSD1306_LINE				=	SSD1306_HEIGHT / 8,			//!< １行あたりのバイト数
	} ;

	//! SSD1306 データ
	typedef struct {
		int							fd ;							//!< ファイルディスクリプタ
		uint8_t						padding[3] ;					//!< パディング
		uint8_t						control ;						//!< コントロールコマンド
		union {
			uint8_t					b[SSD1306_WIDTH][SSD1306_HEIGHT/8] ;
																	//!< バイトアクセスデータ
			uint8_t					l[SSD1306_WIDTH][SSD1306_HEIGHT/32] ;
																	//!< ロングアクセスデータ
		} vram ;													//!< VRAM
	} SSD1306DATA ;


extern int  ssd1306_init(SSD1306DATA *p_data, const char *p_name) ;
extern void ssd1306_uninit( SSD1306DATA *p_data ) ;
extern int  ssd1306_update( SSD1306DATA *p_data ) ;
extern int  ssd1306_display(SSD1306DATA *p_data, bool on) ;
extern int  ssd1306_contrast(SSD1306DATA *p_data, uint8_t value) ;
extern void ssd1306_clear( SSD1306DATA *p_data ) ;
extern void ssd1306_clearLine(SSD1306DATA *p_data, int line, int x, int width, int height) ;
extern void ssd1306_drawImageLine(SSD1306DATA *p_data, int line, int x, int width, int height, const uint8_t *p_image) ;
extern void ssd1306_invertLine(SSD1306DATA *p_data, int line, int x, int width, int height) ;
extern void ssd1306_grayLine(SSD1306DATA *p_data, int line, int x, int width, int height) ;
extern void ssd1306_line(SSD1306DATA *p_data, int sx, int sy, int ex, int ey) ;


#endif//__BTRADIO__SSD1306_H__INCLUDED__
