// -------------------------------------------------------------------------------- 
//!  @file  wlan.c                                                                  
//!  無線 LAN 処理のソースファイル                                                  
//                                                                                  
//   Copyright (C) 2024 lsluk, All rights reserved.                                 
//   http://vdmgr.g2.xrea.com/index.html                                            
// -------------------------------------------------------------------------------- 
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/ioctl.h>
#include <sys/socket.h>
#include <unistd.h>
#include <linux/wireless.h>
#include "wlan.h"


// -------------------------------------------------------------------------------- 
//!  電波強度を取得                                                                 
//!                                                                                 
//!  @param [in] p_name  インタフェース名                                           
//!  @retval     0-100   電波強度                                                   
//!  @retval     -1      異常終了                                                   
// -------------------------------------------------------------------------------- 
int wlan_getLinkQuality( const char *p_name )
{
	struct ifreq			ifreq ;
	struct iwreq			iwreq ;
	struct iw_statistics	statistics ;
	struct iw_range			range ;
	int						result, fd ;


	fd = socket(AF_INET, SOCK_DGRAM, 0) ;
	if( fd == -1 ) {
		return -1 ;
	}

	memset(&ifreq,      0, sizeof( ifreq )) ;
	memset(&iwreq,      0, sizeof( iwreq )) ;
	memset(&statistics, 0, sizeof( statistics )) ;
	strncpy(&ifreq.ifr_name[0], &p_name[0], sizeof( ifreq.ifr_name )-1) ;
	strncpy(&iwreq.ifr_name[0], &p_name[0], sizeof( iwreq.ifr_name )-1) ;

	do {
		result = ioctl(fd, SIOCGIFFLAGS, &ifreq) ;
		if( result < 0 ) {
			break ;
		}

		if( !(ifreq.ifr_flags&IFF_UP) ) {
			result = -1 ;
			break ;
		}

		iwreq.u.data.pointer = &statistics ;
		iwreq.u.data.length  = sizeof( statistics ) ;
		iwreq.u.data.flags   = 1 ;
		result               = ioctl(fd, SIOCGIWSTATS, &iwreq) ;
		if( result < 0 ) {
			break ;
		}

		iwreq.u.data.pointer = &range ;
		iwreq.u.data.length  = sizeof( range ) ;
		iwreq.u.data.flags   = 0 ;
		result               = ioctl(fd, SIOCGIWRANGE, &iwreq) ;
		if( result < 0 ) {
			break ;
		}

		result = ((statistics.qual.qual*100)/range.max_qual.qual) ;
	} while( 0 ) ;

	close( fd ) ;

	return result ;
}
